@@ -39,7 +39,6 @@
 #include "mozilla/dom/WorkerRef.h"
 #include "mozilla/dom/WorkerRunnable.h"
 #include "mozilla/dom/WorkerScope.h"
-#include "mozilla/glean/NetwerkMetrics.h"
 #include "mozilla/ipc/BackgroundChild.h"
 #include "mozilla/ipc/IPCStreamUtils.h"
 #include "mozilla/ipc/PBackgroundChild.h"
@@ -643,7 +642,7 @@ already_AddRefed<Promise> FetchRequest(nsIGlobalObject* aGlobal,
 
     auto* backgroundChild =
         mozilla::ipc::BackgroundChild::GetOrCreateForCurrentThread();
-    Unused << NS_WARN_IF(!backgroundChild->SendPFetchConstructor(actor));
+    (void)NS_WARN_IF(!backgroundChild->SendPFetchConstructor(actor));
 
     FetchOpArgs ipcArgs;
 
@@ -675,8 +674,8 @@ already_AddRefed<Promise> FetchRequest(nsIGlobalObject* aGlobal,
       }
       if (thirdPartyUtil) {
         bool thirdParty = false;
-        Unused << thirdPartyUtil->IsThirdPartyWindow(window->GetOuterWindow(),
-                                                     nullptr, &thirdParty);
+        (void)thirdPartyUtil->IsThirdPartyWindow(window->GetOuterWindow(),
+                                                 nullptr, &thirdParty);
         ipcArgs.isThirdPartyContext() = thirdParty;
       }
     } else {
@@ -700,10 +699,18 @@ already_AddRefed<Promise> FetchRequest(nsIGlobalObject* aGlobal,
     ipcArgs.hasCSPEventListener() = false;
     ipcArgs.isWorkerRequest() = false;
 
+    if (window && window->GetBrowsingContext()) {
+      ipcArgs.associatedBrowsingContextID() =
+          window->GetBrowsingContext()->Id();
+    }
+
+    UniquePtr<SerializedStackHolder> stack = GetCurrentStackForNetMonitor(cx);
+    if (stack) {
+      actor->SetOriginStack(std::move(stack));
+    }
+
     actor->DoFetchOp(ipcArgs);
 
-    mozilla::glean::networking::fetch_keepalive_request_count.Get("main"_ns)
-        .Add(1);
     return p.forget();
   } else {
     WorkerPrivate* worker = GetCurrentThreadWorkerPrivate();
@@ -749,7 +756,7 @@ already_AddRefed<Promise> FetchRequest(nsIGlobalObject* aGlobal,
 
       auto* backgroundChild =
           mozilla::ipc::BackgroundChild::GetOrCreateForCurrentThread();
-      Unused << NS_WARN_IF(!backgroundChild->SendPFetchConstructor(actor));
+      (void)NS_WARN_IF(!backgroundChild->SendPFetchConstructor(actor));
 
       FetchOpArgs ipcArgs;
       ipcArgs.request() = IPCInternalRequest();
@@ -792,12 +799,6 @@ already_AddRefed<Promise> FetchRequest(nsIGlobalObject* aGlobal,
 
       actor->DoFetchOp(ipcArgs);
 
-      if (internalRequest->GetKeepalive()) {
-        mozilla::glean::networking::fetch_keepalive_request_count
-            .Get("worker"_ns)
-            .Add(1);
-      }
-
       return p.forget();
     }
     // Dispatch worker fetch to the main thread
@@ -1098,7 +1099,7 @@ void WorkerFetchResolver::OnDataAvailable() {
 
   RefPtr<WorkerDataAvailableRunnable> r =
       new WorkerDataAvailableRunnable(mPromiseProxy->GetWorkerPrivate(), this);
-  Unused << r->Dispatch(mPromiseProxy->GetWorkerPrivate());
+  (void)r->Dispatch(mPromiseProxy->GetWorkerPrivate());
 }
 
 void WorkerFetchResolver::OnResponseEnd(FetchDriverObserver::EndReason aReason,
@@ -1111,7 +1112,7 @@ void WorkerFetchResolver::OnResponseEnd(FetchDriverObserver::EndReason aReason,
 
   FlushConsoleReport();
 
-  Unused << aReasonDetails;
+  (void)aReasonDetails;
 
   RefPtr<WorkerFetchResponseEndRunnable> r = new WorkerFetchResponseEndRunnable(
       mPromiseProxy->GetWorkerPrivate(), this, aReason);
