@@ -62,8 +62,17 @@ void LIRGraph::dump() {
 #endif
 
 LBlock::LBlock(MBasicBlock* from)
-    : block_(from), entryMoveGroup_(nullptr), exitMoveGroup_(nullptr) {
+    : block_(from),
+      entryMoveGroup_(nullptr),
+      exitMoveGroup_(nullptr),
+      isOutOfLine_(false) {
   from->assignLir(this);
+
+  // If branch hinting is enabled, and this block is unlikely to be executed,
+  // it will be generated out of line.
+  if (from->info().branchHintingEnabled() && from->isUnlikelyFrequency()) {
+    isOutOfLine_ = true;
+  }
 }
 
 bool LBlock::init(TempAllocator& alloc) {
